@@ -15,16 +15,22 @@ import logging
 
 import ibm_boto3
 
-
 logger = logging.getLogger(__name__)
 
 
-class ResourceMeta(object):
+class ResourceMeta:
     """
     An object containing metadata about a resource.
     """
-    def __init__(self, service_name, identifiers=None, client=None,
-                 data=None, resource_model=None):
+
+    def __init__(
+        self,
+        service_name,
+        identifiers=None,
+        client=None,
+        data=None,
+        resource_model=None,
+    ):
         #: (``string``) The service name, e.g. 's3'
         self.service_name = service_name
 
@@ -42,8 +48,9 @@ class ResourceMeta(object):
         self.resource_model = resource_model
 
     def __repr__(self):
-        return 'ResourceMeta(\'{0}\', identifiers={1})'.format(
-            self.service_name, self.identifiers)
+        return 'ResourceMeta(\'{}\', identifiers={})'.format(
+            self.service_name, self.identifiers
+        )
 
     def __eq__(self, other):
         # Two metas are equal if their components are all equal
@@ -61,7 +68,7 @@ class ResourceMeta(object):
         return ResourceMeta(service_name, **params)
 
 
-class ServiceResource(object):
+class ServiceResource:
     """
     A base class for resources.
 
@@ -108,22 +115,22 @@ class ServiceResource(object):
                 continue
 
             if name not in self.meta.identifiers:
-                raise ValueError('Unknown keyword argument: {0}'.format(name))
+                raise ValueError(f'Unknown keyword argument: {name}')
 
             setattr(self, '_' + name, value)
 
         # Validate that all identifiers have been set.
         for identifier in self.meta.identifiers:
             if getattr(self, identifier) is None:
-                raise ValueError(
-                    'Required parameter {0} not set'.format(identifier))
+                raise ValueError(f'Required parameter {identifier} not set')
 
     def __repr__(self):
         identifiers = []
         for identifier in self.meta.identifiers:
-            identifiers.append('{0}={1}'.format(
-                identifier, repr(getattr(self, identifier))))
-        return "{0}({1})".format(
+            identifiers.append(
+                f'{identifier}={repr(getattr(self, identifier))}'
+            )
+        return "{}({})".format(
             self.__class__.__name__,
             ', '.join(identifiers),
         )
