@@ -14,20 +14,18 @@
 import logging
 from functools import partial
 
-from .action import ServiceAction
-from .action import WaiterAction
+from ..docs import docstring
+from ..exceptions import ResourceLoadException
+from .action import ServiceAction, WaiterAction
 from .base import ResourceMeta, ServiceResource
 from .collection import CollectionFactory
 from .model import ResourceModel
-from .response import build_identifiers, ResourceHandler
-from ..exceptions import ResourceLoadException
-from ..docs import docstring
-
+from .response import ResourceHandler, build_identifiers
 
 logger = logging.getLogger(__name__)
 
 
-class ResourceFactory(object):
+class ResourceFactory:
     """
     A factory to create new :py:class:`~ibm_boto3.resources.base.ServiceResource`
     classes from a :py:class:`~ibm_boto3.resources.model.ResourceModel`. There are
@@ -35,12 +33,14 @@ class ResourceFactory(object):
     SQS resource) and another on models contained within the service (e.g. an
     SQS Queue resource).
     """
+
     def __init__(self, emitter):
         self._collection_factory = CollectionFactory()
         self._emitter = emitter
 
-    def load_from_definition(self, resource_name,
-                             single_resource_json_definition, service_context):
+    def load_from_definition(
+        self, resource_name, single_resource_json_definition, service_context
+    ):
         """
         Loads a resource from a model, creating a new
         :py:class:`~ibm_boto3.resources.base.ServiceResource` subclass
@@ -62,13 +62,15 @@ class ResourceFactory(object):
         :rtype: Subclass of :py:class:`~ibm_boto3.resources.base.ServiceResource`
         :return: The service or resource class.
         """
-        logger.debug('Loading %s:%s', service_context.service_name,
-                     resource_name)
+        logger.debug(
+            'Loading %s:%s', service_context.service_name, resource_name
+        )
 
         # Using the loaded JSON create a ResourceModel object.
         resource_model = ResourceModel(
-            resource_name, single_resource_json_definition,
-            service_context.resource_json_definitions
+            resource_name,
+            single_resource_json_definition,
+            service_context.resource_json_definitions,
         )
 
         # Do some renaming of the shape if there was a naming collision
@@ -76,12 +78,14 @@ class ResourceFactory(object):
         shape = None
         if resource_model.shape:
             shape = service_context.service_model.shape_for(
-                resource_model.shape)
+                resource_model.shape
+            )
         resource_model.load_rename_map(shape)
 
         # Set some basic info
         meta = ResourceMeta(
-            service_context.service_name, resource_model=resource_model)
+            service_context.service_name, resource_model=resource_model
+        )
         attrs = {
             'meta': meta,
         }
@@ -91,37 +95,50 @@ class ResourceFactory(object):
 
         # Identifiers
         self._load_identifiers(
-            attrs=attrs, meta=meta, resource_name=resource_name,
-            resource_model=resource_model
+            attrs=attrs,
+            meta=meta,
+            resource_name=resource_name,
+            resource_model=resource_model,
         )
 
         # Load/Reload actions
         self._load_actions(
-            attrs=attrs, resource_name=resource_name,
-            resource_model=resource_model, service_context=service_context
+            attrs=attrs,
+            resource_name=resource_name,
+            resource_model=resource_model,
+            service_context=service_context,
         )
 
         # Attributes that get auto-loaded
         self._load_attributes(
-            attrs=attrs, meta=meta, resource_name=resource_name,
+            attrs=attrs,
+            meta=meta,
+            resource_name=resource_name,
             resource_model=resource_model,
-            service_context=service_context)
+            service_context=service_context,
+        )
 
         # Collections and their corresponding methods
         self._load_collections(
-            attrs=attrs, resource_model=resource_model,
-            service_context=service_context)
+            attrs=attrs,
+            resource_model=resource_model,
+            service_context=service_context,
+        )
 
         # References and Subresources
         self._load_has_relations(
-            attrs=attrs, resource_name=resource_name,
-            resource_model=resource_model, service_context=service_context
+            attrs=attrs,
+            resource_name=resource_name,
+            resource_model=resource_model,
+            service_context=service_context,
         )
 
         # Waiter resource actions
         self._load_waiters(
-            attrs=attrs, resource_name=resource_name,
-            resource_model=resource_model, service_context=service_context
+            attrs=attrs,
+            resource_name=resource_name,
+            resource_model=resource_model,
+            service_context=service_context,
         )
 
         # Create the name based on the requested service and resource
@@ -133,9 +150,11 @@ class ResourceFactory(object):
         base_classes = [ServiceResource]
         if self._emitter is not None:
             self._emitter.emit(
-                'creating-resource-class.%s' % cls_name,
-                class_attributes=attrs, base_classes=base_classes,
-                service_context=service_context)
+                f'creating-resource-class.{cls_name}',
+                class_attributes=attrs,
+                base_classes=base_classes,
+                service_context=service_context,
+            )
         return type(str(cls_name), tuple(base_classes), attrs)
 
     def _load_identifiers(self, attrs, meta, resource_model, resource_name):
@@ -147,10 +166,12 @@ class ResourceFactory(object):
         for identifier in resource_model.identifiers:
             meta.identifiers.append(identifier.name)
             attrs[identifier.name] = self._create_identifier(
-                identifier, resource_name)
+                identifier, resource_name
+            )
 
-    def _load_actions(self, attrs, resource_name, resource_model,
-                      service_context):
+    def _load_actions(
+        self, attrs, resource_name, resource_model, service_context
+    ):
         """
         Actions on the resource become methods, with the ``load`` method
         being a special case which sets internal data for attributes, and
@@ -158,17 +179,23 @@ class ResourceFactory(object):
         """
         if resource_model.load:
             attrs['load'] = self._create_action(
-                action_model=resource_model.load, resource_name=resource_name,
-                service_context=service_context, is_load=True)
+                action_model=resource_model.load,
+                resource_name=resource_name,
+                service_context=service_context,
+                is_load=True,
+            )
             attrs['reload'] = attrs['load']
 
         for action in resource_model.actions:
             attrs[action.name] = self._create_action(
-                action_model=action, resource_name=resource_name,
-                service_context=service_context)
+                action_model=action,
+                resource_name=resource_name,
+                service_context=service_context,
+            )
 
-    def _load_attributes(self, attrs, meta, resource_name, resource_model,
-                         service_context):
+    def _load_attributes(
+        self, attrs, meta, resource_name, resource_model, service_context
+    ):
         """
         Load resource attributes based on the resource shape. The shape
         name is referenced in the resource JSON, but the shape itself
@@ -178,12 +205,13 @@ class ResourceFactory(object):
         if not resource_model.shape:
             return
 
-        shape = service_context.service_model.shape_for(
-            resource_model.shape)
+        shape = service_context.service_model.shape_for(resource_model.shape)
 
-        identifiers = dict(
-            (i.member_name, i)
-            for i in resource_model.identifiers if i.member_name)
+        identifiers = {
+            i.member_name: i
+            for i in resource_model.identifiers
+            if i.member_name
+        }
         attributes = resource_model.get_attributes(shape)
         for name, (orig_name, member) in attributes.items():
             if name in identifiers:
@@ -191,14 +219,15 @@ class ResourceFactory(object):
                     resource_name=resource_name,
                     identifier=identifiers[name],
                     member_model=member,
-                    service_context=service_context
+                    service_context=service_context,
                 )
             else:
                 prop = self._create_autoload_property(
                     resource_name=resource_name,
-                    name=orig_name, snake_cased=name,
+                    name=orig_name,
+                    snake_cased=name,
                     member_model=member,
-                    service_context=service_context
+                    service_context=service_context,
                 )
             attrs[name] = prop
 
@@ -213,11 +242,12 @@ class ResourceFactory(object):
             attrs[collection_model.name] = self._create_collection(
                 resource_name=resource_model.name,
                 collection_model=collection_model,
-                service_context=service_context
+                service_context=service_context,
             )
 
-    def _load_has_relations(self, attrs, resource_name, resource_model,
-                            service_context):
+    def _load_has_relations(
+        self, attrs, resource_name, resource_model, service_context
+    ):
         """
         Load related resources, which are defined via a ``has``
         relationship but conceptually come in two forms:
@@ -235,7 +265,7 @@ class ResourceFactory(object):
             attrs[reference.name] = self._create_reference(
                 reference_model=reference,
                 resource_name=resource_name,
-                service_context=service_context
+                service_context=service_context,
             )
 
         for subresource in resource_model.subresources:
@@ -244,11 +274,12 @@ class ResourceFactory(object):
             attrs[subresource.name] = self._create_class_partial(
                 subresource_model=subresource,
                 resource_name=resource_name,
-                service_context=service_context
+                service_context=service_context,
             )
 
         self._create_available_subresources_command(
-            attrs, resource_model.subresources)
+            attrs, resource_model.subresources
+        )
 
     def _create_available_subresources_command(self, attrs, subresources):
         _subresources = [subresource.name for subresource in subresources]
@@ -267,8 +298,9 @@ class ResourceFactory(object):
 
         attrs['get_available_subresources'] = get_available_subresources
 
-    def _load_waiters(self, attrs, resource_name, resource_model,
-                      service_context):
+    def _load_waiters(
+        self, attrs, resource_name, resource_model, service_context
+    ):
         """
         Load resource waiters from the model. Each waiter allows you to
         wait until a resource reaches a specific state by polling the state
@@ -278,13 +310,14 @@ class ResourceFactory(object):
             attrs[waiter.name] = self._create_waiter(
                 resource_waiter_model=waiter,
                 resource_name=resource_name,
-                service_context=service_context
+                service_context=service_context,
             )
 
     def _create_identifier(factory_self, identifier, resource_name):
         """
         Creates a read-only property for identifier attributes.
         """
+
         def get_identifier(self):
             # The default value is set to ``None`` instead of
             # raising an AttributeError because when resources are
@@ -298,16 +331,18 @@ class ResourceFactory(object):
         get_identifier.__doc__ = docstring.IdentifierDocstring(
             resource_name=resource_name,
             identifier_model=identifier,
-            include_signature=False
+            include_signature=False,
         )
 
         return property(get_identifier)
 
-    def _create_identifier_alias(factory_self, resource_name, identifier,
-                                 member_model, service_context):
+    def _create_identifier_alias(
+        factory_self, resource_name, identifier, member_model, service_context
+    ):
         """
         Creates a read-only property that aliases an identifier.
         """
+
         def get_identifier(self):
             return getattr(self, '_' + identifier.name, None)
 
@@ -318,13 +353,19 @@ class ResourceFactory(object):
             attr_name=identifier.member_name,
             event_emitter=factory_self._emitter,
             attr_model=member_model,
-            include_signature=False
+            include_signature=False,
         )
 
         return property(get_identifier)
 
-    def _create_autoload_property(factory_self, resource_name, name,
-                                  snake_cased, member_model, service_context):
+    def _create_autoload_property(
+        factory_self,
+        resource_name,
+        name,
+        snake_cased,
+        member_model,
+        service_context,
+    ):
         """
         Creates a new property on the resource to lazy-load its value
         via the resource's ``load`` method (if it exists).
@@ -339,8 +380,8 @@ class ResourceFactory(object):
                     self.load()
                 else:
                     raise ResourceLoadException(
-                        '{0} has no load method'.format(
-                            self.__class__.__name__))
+                        f'{self.__class__.__name__} has no load method'
+                    )
 
             return self.meta.data.get(name)
 
@@ -351,19 +392,22 @@ class ResourceFactory(object):
             attr_name=snake_cased,
             event_emitter=factory_self._emitter,
             attr_model=member_model,
-            include_signature=False
+            include_signature=False,
         )
 
         return property(property_loader)
 
-    def _create_waiter(factory_self, resource_waiter_model, resource_name,
-                       service_context):
+    def _create_waiter(
+        factory_self, resource_waiter_model, resource_name, service_context
+    ):
         """
         Creates a new wait method for each resource where both a waiter and
         resource model is defined.
         """
-        waiter = WaiterAction(resource_waiter_model,
-                              waiter_resource_name=resource_waiter_model.name)
+        waiter = WaiterAction(
+            resource_waiter_model,
+            waiter_resource_name=resource_waiter_model.name,
+        )
 
         def do_waiter(self, *args, **kwargs):
             waiter(self, *args, **kwargs)
@@ -375,32 +419,40 @@ class ResourceFactory(object):
             service_model=service_context.service_model,
             resource_waiter_model=resource_waiter_model,
             service_waiter_model=service_context.service_waiter_model,
-            include_signature=False
+            include_signature=False,
         )
         return do_waiter
 
-    def _create_collection(factory_self, resource_name, collection_model,
-                           service_context):
+    def _create_collection(
+        factory_self, resource_name, collection_model, service_context
+    ):
         """
         Creates a new property on the resource to lazy-load a collection.
         """
         cls = factory_self._collection_factory.load_from_definition(
-            resource_name=resource_name, collection_model=collection_model,
+            resource_name=resource_name,
+            collection_model=collection_model,
             service_context=service_context,
-            event_emitter=factory_self._emitter)
+            event_emitter=factory_self._emitter,
+        )
 
         def get_collection(self):
             return cls(
-                collection_model=collection_model, parent=self,
-                factory=factory_self, service_context=service_context)
+                collection_model=collection_model,
+                parent=self,
+                factory=factory_self,
+                service_context=service_context,
+            )
 
         get_collection.__name__ = str(collection_model.name)
         get_collection.__doc__ = docstring.CollectionDocstring(
-            collection_model=collection_model, include_signature=False)
+            collection_model=collection_model, include_signature=False
+        )
         return property(get_collection)
 
-    def _create_reference(factory_self, reference_model, resource_name,
-                          service_context):
+    def _create_reference(
+        factory_self, reference_model, resource_name, service_context
+    ):
         """
         Creates a new property on the resource to lazy-load a reference.
         """
@@ -408,16 +460,18 @@ class ResourceFactory(object):
         # or response, so we can re-use the response handlers to
         # build up resources from identifiers and data members.
         handler = ResourceHandler(
-            search_path=reference_model.resource.path, factory=factory_self,
+            search_path=reference_model.resource.path,
+            factory=factory_self,
             resource_model=reference_model.resource,
-            service_context=service_context
+            service_context=service_context,
         )
 
         # Are there any identifiers that need access to data members?
         # This is important when building the resource below since
         # it requires the data to be loaded.
-        needs_data = any(i.source == 'data' for i in
-                         reference_model.resource.identifiers)
+        needs_data = any(
+            i.source == 'data' for i in reference_model.resource.identifiers
+        )
 
         def get_reference(self):
             # We need to lazy-evaluate the reference to handle circular
@@ -433,13 +487,13 @@ class ResourceFactory(object):
 
         get_reference.__name__ = str(reference_model.name)
         get_reference.__doc__ = docstring.ReferenceDocstring(
-            reference_model=reference_model,
-            include_signature=False
+            reference_model=reference_model, include_signature=False
         )
         return property(get_reference)
 
-    def _create_class_partial(factory_self, subresource_model, resource_name,
-                              service_context):
+    def _create_class_partial(
+        factory_self, subresource_model, resource_name, service_context
+    ):
         """
         Creates a new method which acts as a functools.partial, passing
         along the instance's low-level `client` to the new resource
@@ -457,7 +511,7 @@ class ResourceFactory(object):
             resource_cls = factory_self.load_from_definition(
                 resource_name=name,
                 single_resource_json_definition=json_def,
-                service_context=service_context
+                service_context=service_context,
             )
 
             # Assumes that identifiers are in order, which lets you do
@@ -470,20 +524,26 @@ class ResourceFactory(object):
                 for identifier, value in build_identifiers(identifiers, self):
                     positional_args.append(value)
 
-            return partial(resource_cls, *positional_args,
-                           client=self.meta.client)(*args, **kwargs)
+            return partial(
+                resource_cls, *positional_args, client=self.meta.client
+            )(*args, **kwargs)
 
         create_resource.__name__ = str(name)
         create_resource.__doc__ = docstring.SubResourceDocstring(
             resource_name=resource_name,
             sub_resource_model=subresource_model,
             service_model=service_context.service_model,
-            include_signature=False
+            include_signature=False,
         )
         return create_resource
 
-    def _create_action(factory_self, action_model, resource_name,
-                       service_context, is_load=False):
+    def _create_action(
+        factory_self,
+        action_model,
+        resource_name,
+        service_context,
+        is_load=False,
+    ):
         """
         Creates a new method which makes a request to the underlying
         AWS service.
@@ -492,8 +552,7 @@ class ResourceFactory(object):
         # method below is invoked, which allows instances of the resource
         # to share the ServiceAction instance.
         action = ServiceAction(
-            action_model, factory=factory_self,
-            service_context=service_context
+            action_model, factory=factory_self, service_context=service_context
         )
 
         # A resource's ``load`` method is special because it sets
@@ -504,6 +563,7 @@ class ResourceFactory(object):
             def do_action(self, *args, **kwargs):
                 response = action(self, *args, **kwargs)
                 self.meta.data = response
+
             # Create the docstring for the load/reload mehtods.
             lazy_docstring = docstring.LoadReloadDocstring(
                 action_name=action_model.name,
@@ -511,7 +571,7 @@ class ResourceFactory(object):
                 event_emitter=factory_self._emitter,
                 load_model=action_model,
                 service_model=service_context.service_model,
-                include_signature=False
+                include_signature=False,
             )
         else:
             # We need a new method here because we want access to the
@@ -526,12 +586,13 @@ class ResourceFactory(object):
                     self.meta.data = None
 
                 return response
+
             lazy_docstring = docstring.ActionDocstring(
                 resource_name=resource_name,
                 event_emitter=factory_self._emitter,
                 action_model=action_model,
                 service_model=service_context.service_model,
-                include_signature=False
+                include_signature=False,
             )
 
         do_action.__name__ = str(action_model.name)
