@@ -27,24 +27,24 @@ import logging
 
 from ibm_botocore import xform_name
 
-
 logger = logging.getLogger(__name__)
 
 
-class Identifier(object):
+class Identifier:
     """
     A resource identifier, given by its name.
 
     :type name: string
     :param name: The name of the identifier
     """
+
     def __init__(self, name, member_name=None):
         #: (``string``) The name of the identifier
         self.name = name
         self.member_name = member_name
 
 
-class Action(object):
+class Action:
     """
     A service operation action.
 
@@ -55,6 +55,7 @@ class Action(object):
     :type resource_defs: dict
     :param resource_defs: All resources defined in the service
     """
+
     def __init__(self, name, definition, resource_defs):
         self._definition = definition
 
@@ -67,13 +68,14 @@ class Action(object):
         #: (:py:class:`ResponseResource`) This action's resource or ``None``
         self.resource = None
         if 'resource' in definition:
-            self.resource = ResponseResource(definition.get('resource', {}),
-                                             resource_defs)
+            self.resource = ResponseResource(
+                definition.get('resource', {}), resource_defs
+            )
         #: (``string``) The JMESPath search path or ``None``
         self.path = definition.get('path')
 
 
-class DefinitionWithParams(object):
+class DefinitionWithParams:
     """
     An item which has parameters exposed via the ``params`` property.
     A request has an operation and parameters, while a waiter has
@@ -82,6 +84,7 @@ class DefinitionWithParams(object):
     :type definition: dict
     :param definition: The JSON definition
     """
+
     def __init__(self, definition):
         self._definition = definition
 
@@ -100,7 +103,7 @@ class DefinitionWithParams(object):
         return params
 
 
-class Parameter(object):
+class Parameter:
     """
     An auto-filled parameter which has a source and target. For example,
     the ``QueueUrl`` may be auto-filled from a resource's ``url`` identifier
@@ -113,8 +116,10 @@ class Parameter(object):
     :type source: string
     :param source: The source name, e.g. ``Url``
     """
-    def __init__(self, target, source, name=None, path=None, value=None,
-                 **kwargs):
+
+    def __init__(
+        self, target, source, name=None, path=None, value=None, **kwargs
+    ):
         #: (``string``) The destination parameter name
         self.target = target
         #: (``string``) Where the source is defined
@@ -138,8 +143,9 @@ class Request(DefinitionWithParams):
     :type definition: dict
     :param definition: The JSON definition
     """
+
     def __init__(self, definition):
-        super(Request, self).__init__(definition)
+        super().__init__(definition)
 
         #: (``string``) The name of the low-level service operation
         self.operation = definition.get('operation')
@@ -154,10 +160,11 @@ class Waiter(DefinitionWithParams):
     :type definition: dict
     :param definition: The JSON definition
     """
+
     PREFIX = 'WaitUntil'
 
     def __init__(self, name, definition):
-        super(Waiter, self).__init__(definition)
+        super().__init__(definition)
 
         #: (``string``) The name of this waiter
         self.name = name
@@ -166,7 +173,7 @@ class Waiter(DefinitionWithParams):
         self.waiter_name = definition.get('waiterName')
 
 
-class ResponseResource(object):
+class ResponseResource:
     """
     A resource response to create after performing an action.
 
@@ -175,6 +182,7 @@ class ResponseResource(object):
     :type resource_defs: dict
     :param resource_defs: All resources defined in the service
     """
+
     def __init__(self, definition, resource_defs):
         self._definition = definition
         self._resource_defs = resource_defs
@@ -195,8 +203,7 @@ class ResponseResource(object):
         identifiers = []
 
         for item in self._definition.get('identifiers', []):
-            identifiers.append(
-                Parameter(**item))
+            identifiers.append(Parameter(**item))
 
         return identifiers
 
@@ -207,8 +214,9 @@ class ResponseResource(object):
 
         :type: :py:class:`ResourceModel`
         """
-        return ResourceModel(self.type, self._resource_defs[self.type],
-                             self._resource_defs)
+        return ResourceModel(
+            self.type, self._resource_defs[self.type], self._resource_defs
+        )
 
 
 class Collection(Action):
@@ -222,6 +230,7 @@ class Collection(Action):
     :type resource_defs: dict
     :param resource_defs: All resources defined in the service
     """
+
     @property
     def batch_actions(self):
         """
@@ -234,7 +243,7 @@ class Collection(Action):
         return self.resource.model.batch_actions
 
 
-class ResourceModel(object):
+class ResourceModel:
     """
     A model representing a resource, defined via a JSON description
     format. A resource has identifiers, attributes, actions,
@@ -248,6 +257,7 @@ class ResourceModel(object):
     :type resource_defs: dict
     :param resource_defs: All resources defined in the service
     """
+
     def __init__(self, name, definition, resource_defs):
         self._definition = definition
         self._resource_defs = resource_defs
@@ -296,7 +306,7 @@ class ResourceModel(object):
         :param shape: The underlying shape for this resource.
         """
         # Meta is a reserved name for resources
-        names = set(['meta'])
+        names = {'meta'}
         self._renamed = {}
 
         if self._definition.get('load'):
@@ -318,8 +328,9 @@ class ResourceModel(object):
                     break
 
             if not data_required:
-                self._load_name_with_category(names, name, 'subresource',
-                                              snake_case=False)
+                self._load_name_with_category(
+                    names, name, 'subresource', snake_case=False
+                )
             else:
                 self._load_name_with_category(names, name, 'reference')
 
@@ -327,15 +338,15 @@ class ResourceModel(object):
             self._load_name_with_category(names, name, 'collection')
 
         for name in self._definition.get('waiters', {}):
-            self._load_name_with_category(names, Waiter.PREFIX + name,
-                                          'waiter')
+            self._load_name_with_category(
+                names, Waiter.PREFIX + name, 'waiter'
+            )
 
         if shape is not None:
             for name in shape.members.keys():
                 self._load_name_with_category(names, name, 'attribute')
 
-    def _load_name_with_category(self, names, name, category,
-                                 snake_case=True):
+    def _load_name_with_category(self, names, name, category, snake_case=True):
         """
         Load a name with a given category, possibly renaming it
         if that name is already in use. The name will be stored
@@ -355,15 +366,18 @@ class ResourceModel(object):
             name = xform_name(name)
 
         if name in names:
-            logger.debug('Renaming %s %s %s' % (self.name, category, name))
+            logger.debug(f'Renaming {self.name} {category} {name}')
             self._renamed[(category, name)] = name + '_' + category
             name += '_' + category
 
             if name in names:
                 # This isn't good, let's raise instead of trying to keep
                 # renaming this value.
-                raise ValueError('Problem renaming {0} {1} to {2}!'.format(
-                    self.name, category, name))
+                raise ValueError(
+                    'Problem renaming {} {} to {}!'.format(
+                        self.name, category, name
+                    )
+                )
 
         names.add(name)
 
@@ -411,8 +425,9 @@ class ResourceModel(object):
             if snake_cased in identifier_names:
                 # Skip identifiers, these are set through other means
                 continue
-            snake_cased = self._get_name('attribute', snake_cased,
-                                         snake_case=False)
+            snake_cased = self._get_name(
+                'attribute', snake_cased, snake_case=False
+            )
             attributes[snake_cased] = (name, member)
 
         return attributes
@@ -524,17 +539,12 @@ class ResourceModel(object):
                     #   }
                     # }
                     #
-                    fake_has = {
-                        'resource': {
-                            'type': name,
-                            'identifiers': []
-                        }
-                    }
+                    fake_has = {'resource': {'type': name, 'identifiers': []}}
 
                     for identifier in resource_def.get('identifiers', []):
-                        fake_has['resource']['identifiers'].append({
-                            'target': identifier['name'], 'source': 'input'
-                        })
+                        fake_has['resource']['identifiers'].append(
+                            {'target': identifier['name'], 'source': 'input'}
+                        )
 
                     definition[name] = fake_has
         else:
@@ -549,7 +559,7 @@ class ResourceModel(object):
         :type subresources: bool
         :param subresources: ``True`` to get sub-resources, ``False`` to
                              get references.
-        :rtype: list(:py:class:`ResponseResource`)
+        :rtype: list(:py:class:`Action`)
         """
         resources = []
 
@@ -578,7 +588,7 @@ class ResourceModel(object):
         """
         Get a list of sub-resources.
 
-        :type: list(:py:class:`ResponseResource`)
+        :type: list(:py:class:`Action`)
         """
         return self._get_related_resources(True)
 
@@ -587,7 +597,7 @@ class ResourceModel(object):
         """
         Get a list of reference resources.
 
-        :type: list(:py:class:`ResponseResource`)
+        :type: list(:py:class:`Action`)
         """
         return self._get_related_resources(False)
 
