@@ -68,8 +68,7 @@ def build_identifiers(identifiers, parent, params=None, raw_response=None):
             # This value is set by the user, so ignore it here
             continue
         else:
-            raise NotImplementedError(
-                'Unsupported source type: {0}'.format(source))
+            raise NotImplementedError(f'Unsupported source type: {source}')
 
         results.append((xform_name(target), value))
 
@@ -111,8 +110,10 @@ def build_empty_response(search_path, operation_name, service_model):
                 shape = shape.member
             else:
                 raise NotImplementedError(
-                    'Search path hits shape type {0} from {1}'.format(
-                        shape.type_name, item))
+                    'Search path hits shape type {} from {}'.format(
+                        shape.type_name, item
+                    )
+                )
 
     # Anything not handled here is set to None
     if shape.type_name == 'structure':
@@ -125,7 +126,7 @@ def build_empty_response(search_path, operation_name, service_model):
     return response
 
 
-class RawHandler(object):
+class RawHandler:
     """
     A raw action response handler. This passed through the response
     dictionary, optionally after performing a JMESPath search if one
@@ -136,6 +137,7 @@ class RawHandler(object):
     :rtype: dict
     :return: Service response
     """
+
     def __init__(self, search_path):
         self.search_path = search_path
 
@@ -155,7 +157,7 @@ class RawHandler(object):
         return response
 
 
-class ResourceHandler(object):
+class ResourceHandler:
     """
     Creates a new resource or list of new resources from the low-level
     response based on the given response resource definition.
@@ -180,8 +182,15 @@ class ResourceHandler(object):
     :rtype: ServiceResource or list
     :return: New resource instance(s).
     """
-    def __init__(self, search_path, factory, resource_model,
-                 service_context, operation_name=None):
+
+    def __init__(
+        self,
+        search_path,
+        factory,
+        resource_model,
+        service_context,
+        operation_name=None,
+    ):
         self.search_path = search_path
         self.factory = factory
         self.resource_model = resource_model
@@ -199,13 +208,14 @@ class ResourceHandler(object):
         """
         resource_name = self.resource_model.type
         json_definition = self.service_context.resource_json_definitions.get(
-            resource_name)
+            resource_name
+        )
 
         # Load the new resource class that will result from this action.
         resource_cls = self.factory.load_from_definition(
             resource_name=resource_name,
             single_resource_json_definition=json_definition,
-            service_context=self.service_context
+            service_context=self.service_context,
         )
         raw_response = response
         search_response = None
@@ -222,9 +232,11 @@ class ResourceHandler(object):
         # will have one item consumed from the front of the list for each
         # resource that is instantiated. Items which are not a list will
         # be set as the same value on each new resource instance.
-        identifiers = dict(build_identifiers(
-            self.resource_model.identifiers, parent, params,
-            raw_response))
+        identifiers = dict(
+            build_identifiers(
+                self.resource_model.identifiers, parent, params, raw_response
+            )
+        )
 
         # If any of the identifiers is a list, then the response is plural
         plural = [v for v in identifiers.values() if isinstance(v, list)]
@@ -242,13 +254,16 @@ class ResourceHandler(object):
                 if search_response:
                     response_item = search_response[i]
                 response.append(
-                    self.handle_response_item(resource_cls, parent,
-                                              identifiers, response_item))
+                    self.handle_response_item(
+                        resource_cls, parent, identifiers, response_item
+                    )
+                )
         elif all_not_none(identifiers.values()):
             # All identifiers must always exist, otherwise the resource
             # cannot be instantiated.
             response = self.handle_response_item(
-                resource_cls, parent, identifiers, search_response)
+                resource_cls, parent, identifiers, search_response
+            )
         else:
             # The response should be empty, but that may mean an
             # empty dict, list, or None based on whether we make
@@ -259,13 +274,16 @@ class ResourceHandler(object):
                 # A remote service call was made, so try and determine
                 # its shape.
                 response = build_empty_response(
-                    self.search_path, self.operation_name,
-                    self.service_context.service_model)
+                    self.search_path,
+                    self.operation_name,
+                    self.service_context.service_model,
+                )
 
         return response
 
-    def handle_response_item(self, resource_cls, parent, identifiers,
-                             resource_data):
+    def handle_response_item(
+        self, resource_cls, parent, identifiers, resource_data
+    ):
         """
         Handles the creation of a single response item by setting
         parameters and creating the appropriate resource instance.
