@@ -13,11 +13,14 @@
 import sys
 from collections import namedtuple
 
-
 _ServiceContext = namedtuple(
     'ServiceContext',
-    ['service_name', 'service_model', 'service_waiter_model',
-     'resource_json_definitions']
+    [
+        'service_name',
+        'service_model',
+        'service_waiter_model',
+        'resource_json_definitions',
+    ],
 )
 
 
@@ -40,6 +43,7 @@ class ServiceContext(_ServiceContext):
         shapes for a service. It is equivalient of loading a
         ``resource-1.json`` and retrieving the value at the key "resources".
     """
+
     pass
 
 
@@ -68,13 +72,14 @@ def lazy_call(full_name, **kwargs):
 def inject_attribute(class_attributes, name, value):
     if name in class_attributes:
         raise RuntimeError(
-            'Cannot inject class attribute "%s", attribute '
-            'already exists in class dict.' % name)
+            f'Cannot inject class attribute "{name}", attribute '
+            f'already exists in class dict.'
+        )
     else:
         class_attributes[name] = value
 
 
-class LazyLoadedWaiterModel(object):
+class LazyLoadedWaiterModel:
     """A lazily loaded waiter model
 
     This does not load the service waiter model until an attempt is made
@@ -83,6 +88,7 @@ class LazyLoadedWaiterModel(object):
     the waiter-2.json until it is accessed through a ``get_waiter`` call
     when the docstring is generated/accessed.
     """
+
     def __init__(self, bc_session, service_name, api_version):
         self._session = bc_session
         self._service_name = service_name
@@ -90,4 +96,5 @@ class LazyLoadedWaiterModel(object):
 
     def get_waiter(self, waiter_name):
         return self._session.get_waiter_model(
-            self._service_name, self._api_version).get_waiter(waiter_name)
+            self._service_name, self._api_version
+        ).get_waiter(waiter_name)
